%define build_sys_rootcerts 1
%{?_without_sys_rootcerts: %{expand: %%global build_sys_rootcerts 0}}

%define qtcryptodir %{qt4plugins}/crypto

%define oname qca
%define major 2
%define libname %mklibname %{oname} %{major}
%define devname %mklibname %{oname} -d

Summary:	Straightforward and cross-platform crypto API for Qt
Name:		qca2
Version:	2.0.3
Release:	5
License:	LGPLv2.1+
Group:		System/Libraries
Url:		http://delta.affinix.com/qca
# From kde support module
Source0:	%{oname}-%{version}.tar.xz
Patch0:		qca-2.0.3-gcc.patch
BuildRequires:	cmake
%if %{build_sys_rootcerts}
BuildRequires:	rootcerts
%endif
BuildRequires:	qt4-devel
BuildRequires:	sasl-devel
BuildRequires:	pkgconfig(libgcrypt)
BuildRequires:	pkgconfig(nss)

%description
The QCA library provides an easy API for a range of cryptographic
features, including SSL/TLS, X.509 certificates, SASL, symmetric
ciphers, public key ciphers, hashes and much more.

Functionality is supplied via plugins. This is useful for avoiding
dependence on a particular crypto library and makes upgrading easier,
as there is no need to recompile your application when adding or
upgrading a crypto plugin. Also, by pushing crypto functionality into
plugins, applications are free of legal issues, such as export
regulation.

%files
%doc README COPYING INSTALL TODO
%{_mandir}/man1/*
%defattr(0755,root,root,0755)
%{qt4dir}/bin/qcatool2

#------------------------------------------------------------------------------

%if ! %{build_sys_rootcerts}
%package -n %{name}-root-certificates
Summary:	Common root CA certificates for QCA
Group:		System/Libraries
Requires:	%{libname} = %{EVRD}

%description	-n %{name}-root-certificates
Provides root Certificate Authority certificates for the QCA library.
These certificates are the same ones that are included in Mozilla.

%files -n %{name}-root-certificates
%dir %{qt4dir}/share/qca
%dir %{qt4dir}/share/qca/certs
%doc %{qt4dir}/share/qca/certs/README
%{qt4dir}/share/qca/certs/rootcerts.pem
%endif

#------------------------------------------------------------------------------

%package -n %{libname}
Summary:	Libraries for QCA
Group:		System/Libraries
%if %{build_sys_rootcerts}
Requires:	rootcerts
Obsoletes:	%{name}-root-certificates < %{version}-%{release}
%else
Requires:	%{name}-root-certificates >= %{EVRD}
%endif

%description -n %{libname}
Libraries for QCA.

%files -n %{libname}
%dir %{qtcryptodir}
%defattr(0755,root,root,0755)
%{qt4lib}/libqca.so.%{major}*

#------------------------------------------------------------------------------

%package -n %{devname}
Summary:	Development files for QCA
Group:		Development/KDE and Qt
Requires:	%{libname} = %{EVRD}
Provides:	%{name}-devel = %{EVRD}
Provides:	%{mklibname qca 2 -d} = %{EVRD}

%description -n %{devname}
Development files for QCA.

%files -n %{devname}
%{_libdir}/pkgconfig/qca2.pc
%{qt4dir}/mkspecs/features/crypto.prf
%dir %{qt4include}/QtCrypto
%{qt4include}/QtCrypto/*
%{qt4lib}/libqca.so

#------------------------------------------------------------------------------

%package plugin-gnupg
Summary:	GnuPG plugin for QCA
Group:		Development/KDE and Qt
Provides:	qca2-gnupg = %{EVRD}
Provides:	qca-gnupg = %{EVRD}
Provides:	%{libname}-plugin-gnupg = %{EVRD}
Provides:	qca2-plugin-gnupg-%{_lib} = %{EVRD}
Obsoletes:	qca2-plugin-gnupg-%{_lib} < 2.0.0-5

%description plugin-gnupg
This is a plugin to provide GnuPG capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-gnupg
%attr(0755,root,root) %{qt4plugins}/crypto/libqca-gnupg.*

#------------------------------------------------------------------------------

%package plugin-openssl
Summary:	OpenSSL plugin for QCA
Group:		Development/KDE and Qt
BuildRequires:	pkgconfig(openssl)
Provides:	qca2-openssl = %{EVRD}
Provides:	qca-ossl = %{EVRD}
Provides:	qca2-tls = %{EVRD}
Provides:	%{libname}-plugin-openssl = %{EVRD}
Provides:	qca2-plugin-openssl-%{_lib} = %{EVRD}
Obsoletes:	qca2-plugin-openssl-%{_lib} < 2.0.0-5

%description plugin-openssl
This is a plugin to provide OpenSSL capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-openssl
%attr(0755,root,root) %{qt4plugins}/crypto/libqca-ossl.*

#------------------------------------------------------------------------------

%package plugin-pkcs11
Summary:	PKCS11 plugin for QCA
Group:		Development/KDE and Qt
BuildRequires:	pkgconfig(openssl)
BuildRequires:	pkgconfig(libpkcs11-helper-1)
Provides:	qca2-pkcs11 = %{EVRD}
Provides:	qca2-plugin-pkcs11-%{_lib} = %{EVRD}
Obsoletes:	qca2-plugin-pkcs11-%{_lib} < 2.0.0-5
Provides:	%{libname}-plugin-pkcs11 = %{EVRD}

%description plugin-pkcs11
This is a plugin to provide PKCS11 capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-pkcs11
%attr(0755,root,root) %{qt4plugins}/crypto/libqca-pkcs11.*

#------------------------------------------------------------------------------

%package plugin-cyrus-sasl
Summary:	Cyrus-sasl plugin for QCA
Group:		Development/KDE and Qt
BuildRequires:	libsasl2-devel
Provides:	qca2-sasl = %{EVRD}
Provides:	qca2-plugin-cyrus-sasl-%{_lib} = %{EVRD}
Obsoletes:	qca2-plugin-cyrus-sasl-%{_lib} < 2.0.0-5
Provides:	%{libname}-plugin-cyrus-sasl = %{EVRD}

%description plugin-cyrus-sasl
This is a plugin to provide cyrus-sasl capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-cyrus-sasl
%attr(0755,root,root) %{qt4plugins}/crypto/libqca-cyrus-sasl.*

#------------------------------------------------------------------------------

%package plugin-logger
Summary:	Logger plugin for QCA
Group:		Development/KDE and Qt
Provides:	qca2-logger = %{EVRD}
Provides:	qca2-plugin-logger-%{_lib} = %{EVRD}
Obsoletes:	qca2-plugin-logger-%{_lib} < 2.0.0-5
Provides:	%{libname}-plugin-logger = %{EVRD}

%description plugin-logger
This is a plugin to provide logger capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-logger
%attr(0755,root,root) %{qt4plugins}/crypto/libqca-logger.*

#------------------------------------------------------------------------------

%package plugin-gcrypt
Summary:	Logger plugin for QCA
Group:		Development/KDE and Qt
Provides:	qca2-gcrypt = %{EVRD}
Provides:	qca2-plugin-gcrypt-%{_lib} = %{EVRD}
Obsoletes:	qca2-plugin-gcrypt-%{_lib} < 2.0.0-5
Provides:	%{libname}-plugin-gcrypt = %{EVRD}

%description plugin-gcrypt
This is a plugin to provide gcrypt capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-gcrypt
%attr(0755,root,root) %{qt4plugins}/crypto/libqca-gcrypt.*

#------------------------------------------------------------------------------

%package plugin-nss
Summary:	Logger plugin for QCA
Group:		Development/KDE and Qt
Provides:	qca2-nss = %{EVRD}
Provides:	qca2-plugin-nss-%{_lib} = %{EVRD}
Obsoletes:	qca2-plugin-nss-%{_lib} < 2.0.0-5
Provides:	%{libname}-plugin-nss = %{EVRD}

%description plugin-nss
This is a plugin to provide nss capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-nss
%attr(0755,root,root) %{qt4plugins}/crypto/libqca-nss.*

#------------------------------------------------------------------------------

%package plugin-softstore
Summary:	Logger plugin for QCA
Group:		Development/KDE and Qt
Provides:	qca2-softstore = %{EVRD}
Provides:	qca2-plugin-softstore-%{_lib} = %{EVRD}
Obsoletes:	qca2-plugin-softstore-%{_lib} < 2.0.0-5
Provides:	%{libname}-plugin-softstore = %{EVRD}

%description plugin-softstore
This is a plugin to provide softstore capability to programs that
utilize the Qt Cryptographic Architecture (QCA).

%files plugin-softstore
%attr(0755,root,root) %{qt4plugins}/crypto/libqca-softstore.*

#------------------------------------------------------------------------------

%prep
%setup -q -n %{oname}-%{version}
%patch0 -p1

%build
%cmake_qt4 \
	-DCMAKE_INSTALL_PREFIX=%{qt4dir} \
	-DLIB_INSTALL_DIR=%{_libdir} \
	-DPKGCONFIG_INSTALL_PREFIX=%{_libdir}/pkgconfig
%make


%install
%makeinstall_std -C build

# Make directory for plugins
install -d -m 755 %{buildroot}/%{qtcryptodir}

mkdir -p %{buildroot}%{_mandir}
mv %{buildroot}%{qt4dir}/share/man/man1 %{buildroot}%{_mandir}


%changelog
* Mon Jul 21 2014 Andrey Bondrov <andrey.bondrov@rosalab.ru> 2.0.3-5
+ Revision: 605e9c9
- Spec cleanup


